# ortools-stubs: unofficial typing stubs for Google OR-Tools

[![PyPI version](https://badge.fury.io/py/ortools-stubs.svg)](https://pypi.org/project/ortools-stubs/)
[![PyPI download](https://img.shields.io/pypi/dm/ortools-stubs.svg)](https://pypi.org/project/ortools-stubs/#files)

[PEP 484](https://www.python.org/dev/peps/pep-0484/)
typing annotations for the `proto` files in [ortools](https://github.com/google/or-tools) using [mypy-protobuf](https://github.com/dropbox/mypy-protobuf).

## Installation
Following [PEP 561](https://www.python.org/dev/peps/pep-0561/), it is released as a separate package.

```pip install ortools-stubs```

## Note
This is a temporary solution, it would be better to generate these files in the main package.

* https://github.com/google/or-tools/issues/1547
* https://github.com/google/or-tools/pull/1544
